@@ -37,8 +37,14 @@ define(function(require) {
     },
 
     addOne: function(model) {
+      var _this = this;
       var view = new CStatView({model: model});
       var vel = view.render().el;
+      view.on("dragStart", _.bind(this.trigger, this, "dragStart"));
+      view.on("drag",      _.bind(this.trigger, this, "drag"));
+      view.on("dragEnd",   _.bind(this.trigger, this, "dragEnd"));
+
+
       this.$el.append(vel);
     }
   });
